@@ -25,3 +25,15 @@ mlr3tuning::TuningInstanceMultiCrit
 #' @importFrom mlr3tuning extract_inner_tuning_results
 #' @export
 mlr3tuning::extract_inner_tuning_results
+
+#' @importFrom mlr3tuning tune
+#' @export
+mlr3tuning::tune
+
+#' @importFrom mlr3tuning tune_nested
+#' @export
+mlr3tuning::tune_nested
+
+#' @importFrom mlr3tuning auto_tuner
+#' @export
+mlr3tuning::auto_tuner
